@@ -2,7 +2,7 @@ import unittest
 import pandas as pd
 import re
 
-from demyst.common import PII_REGEX, is_value
+from demyst.common import PII_REGEX
 
 # Mask columns in dataframe that match PII_REGEX.  If columns
 # parameter is specified, mask only those columns, ignoring PII_REGEX.
@@ -24,8 +24,11 @@ def __find_columns_to_mask(df, columns):
 
 def __mask_column(series):
     def mask(value):
-        if is_value(value):
+        if __is_value(value):
             return "Masked"
         else:
             return value
     return series.map(mask)
+
+def __is_value(value):
+    return not(pd.isna(value) or (isinstance(value, str) and value.strip() == ""))
